# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.
#
# This source code is licensed under the license found in the
# LICENSE file in the root directory of this source tree.

if __name__ == "__main__":
    print("Text Watermarking - To be released soon.")
    print("Powered by Pytorch")
    print("Copyright Meta AI")
